@@ -38,6 +38,7 @@ class StreamLiker(YSL):
         self.total_time_elapsed = 0
         self.time_ended = None
 
+        self.active_streams = []
         self.currently_streaming = {}
         self.streams_liked = {}
         self.streams_liked_id = []
@@ -53,7 +54,7 @@ class StreamLiker(YSL):
         self.driver = None
         self.options = FirefoxOptions()
 
-        self.version = 1.4
+        self.version = "1.4.1"
 
     def clear_data(self):
         self.start_time = None
@@ -77,19 +78,24 @@ class StreamLiker(YSL):
 
     def is_streaming(self):
 
-        ##### Status Code
-        print('Checking for streams...')
-        print()
+        try:
+            ##### Status Code
+            print('Checking for streams...')
+            print()
 
-        for name in self.channels.keys():
-            channel_url = 'https://www.youtube.com/channel/' + self.channels[name]
-            response = requests.get(channel_url).text
-            stream_active = '{"text":" watching"}' in response
-            if stream_active:
-                self.currently_streaming[name] = channel_url
-                self.number_of_active_streams += 1
+            for name in self.channels.keys():
+                channel_url = 'https://www.youtube.com/channel/' + self.channels[name]
+                response = requests.get(channel_url).text
+                stream_active = '{"text":" watching"}' in response
+                if stream_active:
+                    self.currently_streaming[name] = channel_url
+                    self.number_of_active_streams += 1
+                    print(f"{name} is currently streaming.")
 
-        self.stream_data['No. of active streams'] = self.number_of_active_streams
+            self.stream_data['No. of active streams'] = self.number_of_active_streams
+            print()
+        except:
+            assert False, "is_streamingError: MaxConnection Pool. Restart the program"
 
     def like_videos(self):
 
@@ -112,8 +118,8 @@ class StreamLiker(YSL):
                 email.send_keys(EMAIL)
                 email.send_keys(Keys.RETURN)
             except:
-                print('There is a problem in the email idk lmao, driver quitting')
                 self.driver_quit()
+                assert False, "GoogleEmailError: Cannot find XPATH."
 
             time.sleep(5)
 
@@ -127,8 +133,8 @@ class StreamLiker(YSL):
                 password.send_keys(PASSWORD)
                 password.send_keys(Keys.RETURN)
             except:
-                print("Password textbox not found")
                 self.driver_quit()
+                assert False, "GooglePasswordError: Cannot find XPATH."
 
             time.sleep(5)
 
@@ -144,8 +150,9 @@ class StreamLiker(YSL):
                     )
                     link = video_url.get_attribute('href')
                 except:
-                    print("lol getting link error")
+                    assert False, "LinkFetchError: Cannot find XPATH."
 
+                self.active_streams.append(link[32:])
                 self.driver.get(link)
 
                 try:
@@ -158,8 +165,8 @@ class StreamLiker(YSL):
                         print(f"Video from {name} is already liked.")
 
                 except:
-                    print("like button error or something idk")
                     self.driver_quit()
+                    assert False, "LikeButtonError: Cannot find XPATH."
 
                 if not is_liked:
                     self.video_ids.append(link[32:])
